import axios from 'axios'
import { ElMessage, ElMessageBox } from 'element-plus'
import router from '../router'
import { API_BASE_URL } from '../config/api.config'

const request = axios.create({
  baseURL: API_BASE_URL,
  timeout: 10000,
  headers: {
    'Content-Type': 'application/json'
  }
})

// 请求拦截器
request.interceptors.request.use(
  config => {
    // 如果不是登录请求，就添加token
    if (!config.url.includes('/user/login') && !config.url.includes('/user/register')) {
      const token = JSON.parse(localStorage.getItem('token')).token
      if (token) {
        config.headers.Authorization = `Bearer ${token}`
      }
      console.log('Request Headers:', config.headers.Authorization)
    }
    return config
  },
  error => {
    return Promise.reject(error)
  }
)

// 响应拦截器
request.interceptors.response.use(
  response => {
    const { data } = response
    console.log('Response Data:', data)
    
    if (data.retcode === 0) {
      return data
    }
    // 显示错误消息对话框
    ElMessageBox.alert(data.message || '操作失败', '错误', {
      type: 'error',
      confirmButtonText: '确定'
    })
    return Promise.reject(new Error(data.message || '操作失败'))
  },
  error => {
    console.error('Request Error:', error)
    
    if (error.response) {
      switch (error.response.status) {
        case 401:
          localStorage.removeItem('token')
          localStorage.removeItem('userRole')
          router.push('/login')
          break
        case 403:
          ElMessage.error('没有权限访问')
          break
        default:
          ElMessage.error(error.response.data?.message || '请求失败')
      }
    } else if (error.request) {
      // 请求已发出但没有收到响应
      ElMessage.error('服务器无响应，请检查后端服务是否启动')
    } else {
      // 请求配置出错
      ElMessage.error('请求配置错误')
    }
    return Promise.reject(error)
  }
)

export default request 